SelfControlledCohort-package: SelfControlledCohort: Self-Controlled Cohort Population-Level...

SelfControlledCohort-packageR Documentation

SelfControlledCohort: Self-Controlled Cohort Population-Level Estimation

Description

Estimates incidence rate ratios by comparing time exposed with time unexposed among an exposed cohort using self-controlled cohort methodology as described in Ryan et al. (2013) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/pds.3457")}. Functions used for empirical calibration of effect estimates, confidence intervals, and p-values are included to control for residual bias.

Author(s)

Maintainer: Jamie Gilbert gilbert@ohdsi.org (ORCID)

Authors:

Other contributors:

  • Observational Health Data Science and Informatics [copyright holder]

See Also

Useful links:


SelfControlledCohort documentation built on June 17, 2026, 5:07 p.m.