createResultsDataModel: Create the results data model tables on a database server.

View source: R/ResultsDataModel.R

createResultsDataModelR Documentation

Create the results data model tables on a database server.

Description

Create the results data model tables on a database server.

Usage

createResultsDataModel(
  connectionDetails = NULL,
  databaseSchema,
  tablePrefix = ""
)

Arguments

connectionDetails

DatabaseConnector connectionDetails instance @seealso[DatabaseConnector::createConnectionDetails]

databaseSchema

The schema on the server where the tables will be created.

tablePrefix

(Optional) string to insert before table names for database table names

Details

Only PostgreSQL and SQLite servers are supported.

Value

Invisibly returns NULL. Creates database tables for results storage as a side effect.

Examples


if (interactive()) {
connectionDetails <- DatabaseConnector::createConnectionDetails(
  dbms = "sqlite",
  server = "myResults.db"
)

createResultsDataModel(
  connectionDetails = connectionDetails,
  databaseSchema = "main"
)
}


SelfControlledCohort documentation built on June 17, 2026, 5:07 p.m.