View source: R/StrategusModuleFunctions.R
| getResultsFolders | R Documentation |
Get results folders for an analysis specification
getResultsFolders(analysisSpecification, exportFolder)
analysisSpecification |
An analysis specification object containing analysis settings and exposure-outcome pairs. |
exportFolder |
The base folder where results are exported. Individual analysis results will be in subfolders named A_analysisId. |
A character vector of paths to results folders for each analysis setting.
if (interactive())
resultsFolders <- getResultsFolders(analysisSpec, tempdir())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.