Write a list of objects of type sccAnalysis to file. The file is in JSON format.

saveSccAnalysisList(sccAnalysisList, file)

Arguments

sccAnalysisList

The sccAnalysis list to be written to file

file

The name of the file where the results will be written

Value

Invisibly returns NULL. Saves the analysis list to file as a side effect.

Examples

if (FALSE) { # \dontrun{
analysis1 <- createSccAnalysis(analysisId = 1,
                              description = "30-day risk window",
                              runSelfControlledCohortArgs = createRunSelfControlledCohortArgs())
saveSccAnalysisList(list(analysis1), "analyses.json")
} # }