View source: R/ResultsDataModel.R
| uploadResults | R Documentation |
Requires the results data model tables have been created using the createResultsDataModel function.
uploadResults(
connectionDetails,
schema,
resultsFolder,
forceOverWriteOfSpecifications = FALSE,
purgeSiteDataBeforeUploading = FALSE,
tablePrefix = "",
...
)
connectionDetails |
An object of type |
schema |
The schema on the server where the tables have been created. |
resultsFolder |
Path to result files |
forceOverWriteOfSpecifications |
If TRUE, specifications of the phenotypes, cohort definitions, and analysis will be overwritten if they already exist on the database. Only use this if these specifications have changed since the last upload. |
purgeSiteDataBeforeUploading |
If TRUE, before inserting data for a specific databaseId all the data for that site will be dropped. This assumes the input zip file contains the full data for that data site. |
tablePrefix |
(Optional) string to insert before table names for database table names |
... |
See ResultModelManager::uploadResults |
Invisibly returns NULL. Uploads results to the database as a side effect.
if (interactive()) {
connectionDetails <- DatabaseConnector::createDonnectionDetails(
dbms = "sqlite",
server = "myResults.db"
)
uploadResults(
connectionDetails = connectionDetails,
schema = "main",
resultsFolder = tempdir()
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.