| SelfControlledCohort-package | R Documentation |
Estimates incidence rate ratios by comparing time exposed with time unexposed among an exposed cohort using self-controlled cohort methodology as described in Ryan et al. (2013) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/pds.3457")}. Functions used for empirical calibration of effect estimates, confidence intervals, and p-values are included to control for residual bias.
Maintainer: Jamie Gilbert gilbert@ohdsi.org (ORCID)
Authors:
Jamie Gilbert gilbert@ohdsi.org (ORCID)
Martijn Schuemie schuemie@ohdsi.org
Patrick Ryan
Other contributors:
Observational Health Data Science and Informatics [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.