| createExposureOutcome | R Documentation |
Create exposure-outcome combinations.
createExposureOutcome(exposureId, outcomeId, trueEffectSize = NA)
exposureId |
A concept ID indentifying the drug of interest in the exposure table. If
multiple strategies for picking the exposure will be tested in the analysis,
a named list of numbers can be provided instead. In the analysis, the name
of the number to be used can be specified using the |
outcomeId |
A concept ID indentifying the outcome of interest in the outcome table. If
multiple strategies for picking the outcome will be tested in the analysis,
a named list of numbers can be provided instead. In the analysis, the name
of the number to be used can be specified using the #' |
trueEffectSize |
Should this be set to 1 this will be considererd a negative control |
Create a hypothesis of interest, to be used with the runSccAnalyses function.
An object of class exposureOutcome specifying an exposure-outcome pair for analysis.
if (interactive()) {
# Create a simple exposure-outcome pair
eo1 <- createExposureOutcome(exposureId = 1124300,
outcomeId = 444382)
# Create a negative control (true effect size = 1)
eo2 <- createExposureOutcome(exposureId = 1124300,
outcomeId = 444382,
trueEffectSize = 1)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.