View source: R/ResultsDataModel.R
| createResultsDataModel | R Documentation |
Create the results data model tables on a database server.
createResultsDataModel(
connectionDetails = NULL,
databaseSchema,
tablePrefix = ""
)
connectionDetails |
DatabaseConnector connectionDetails instance @seealso[DatabaseConnector::createConnectionDetails] |
databaseSchema |
The schema on the server where the tables will be created. |
tablePrefix |
(Optional) string to insert before table names for database table names |
Only PostgreSQL and SQLite servers are supported.
Invisibly returns NULL. Creates database tables for results storage as a side effect.
if (interactive()) {
connectionDetails <- DatabaseConnector::createConnectionDetails(
dbms = "sqlite",
server = "myResults.db"
)
createResultsDataModel(
connectionDetails = connectionDetails,
databaseSchema = "main"
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.