View source: R/StrategusModuleFunctions.R
| createSelfControlledCohortModuleSpecifications | R Documentation |
Creates a specifications object for the Self-Controlled Cohort module to be used within the OHDSI Strategus framework.
createSelfControlledCohortModuleSpecifications(
analysisSettings,
exposureOutcomeList,
computeThreads = parallel::detectCores() - 1
)
analysisSettings |
A list of analysis settings containing the analysis configuration and parameters for self-controlled cohort analyses. |
exposureOutcomeList |
A list of objects of type |
computeThreads |
Integer specifying the number of threads to use for parallel computation. Default is the number of available cores minus 1. |
A list object of class 'SelfControlledCohortModuleSpecifications' and 'ModuleSpecifications' containing the module name, version, repository information, and analysis settings.
if (interactive()) {
eo1 <- createExposureOutcome(exposureId = 1124300, outcomeId = 444382)
analysis1 <- createSccAnalysis(analysisId = 1,
description = "Main",
runSelfControlledCohortArgs = createRunSelfControlledCohortArgs())
moduleSpec <- createSelfControlledCohortModuleSpecifications(
analysisSettings = list(analysis1),
exposureOutcomeList = list(eo1)
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.