Get results folders for an analysis specification

getResultsFolders(analysisSpecification, exportFolder)

Arguments

analysisSpecification

An analysis specification object containing analysis settings and exposure-outcome pairs.

exportFolder

The base folder where results are exported. Individual analysis results will be in subfolders named A_analysisId.

Value

A character vector of paths to results folders for each analysis setting.

Examples

if (FALSE) { # \dontrun{
resultsFolders <- getResultsFolders(analysisSpec, "./results")
} # }