Migrate data from current state to next state
It is strongly advised that you have a backup of all data (either sqlite files, a backup database (in the case you are using a postgres backend) or have kept the csv/zip files from your data generation.
migrateDataModel(connectionDetails, databaseSchema, tablePrefix = "")Invisibly returns NULL. Migrates the database schema as a side effect.
if (FALSE) { # \dontrun{
migrateDataModel(
connectionDetails = connectionDetails,
databaseSchema = "results"
)
} # }