saveSccAnalysisList: Save a list of sccAnalysis to file

View source: R/Analyses.R

saveSccAnalysisListR Documentation

Save a list of sccAnalysis to file

Description

Write a list of objects of type sccAnalysis to file. The file is in JSON format.

Usage

saveSccAnalysisList(sccAnalysisList, file)

Arguments

sccAnalysisList

The sccAnalysis list to be written to file

file

The name of the file where the results will be written

Value

Invisibly returns NULL. Saves the analysis list to file as a side effect.

Examples


if (interactive()) {
analysis1 <- createSccAnalysis(analysisId = 1,
                              description = "30-day risk window",
                              runSelfControlledCohortArgs = createRunSelfControlledCohortArgs())
saveSccAnalysisList(list(analysis1), file.path(tempdir(), "analyses.json"))
}


SelfControlledCohort documentation built on June 17, 2026, 5:07 p.m.