| saveSccAnalysisList | R Documentation |
Write a list of objects of type sccAnalysis to file. The file is in JSON format.
saveSccAnalysisList(sccAnalysisList, file)
sccAnalysisList |
The sccAnalysis list to be written to file |
file |
The name of the file where the results will be written |
Invisibly returns NULL. Saves the analysis list to file as a side effect.
if (interactive()) {
analysis1 <- createSccAnalysis(analysisId = 1,
description = "30-day risk window",
runSelfControlledCohortArgs = createRunSelfControlledCohortArgs())
saveSccAnalysisList(list(analysis1), file.path(tempdir(), "analyses.json"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.