Requires the results data model tables have been created using the createResultsDataModel function.
uploadResults(
connectionDetails,
schema,
resultsFolder,
forceOverWriteOfSpecifications = FALSE,
purgeSiteDataBeforeUploading = FALSE,
tablePrefix = "",
...
)An object of type connectionDetails as created using the
createConnectionDetails function in the
DatabaseConnector package.
The schema on the server where the tables have been created.
Path to result files
If TRUE, specifications of the phenotypes, cohort definitions, and analysis will be overwritten if they already exist on the database. Only use this if these specifications have changed since the last upload.
If TRUE, before inserting data for a specific databaseId all the data for that site will be dropped. This assumes the input zip file contains the full data for that data site.
(Optional) string to insert before table names for database table names
See ResultModelManager::uploadResults
Invisibly returns NULL. Uploads results to the database as a side effect.
if (FALSE) { # \dontrun{
uploadResults(
connectionDetails = connectionDetails,
schema = "results",
resultsFolder = "./output"
)
} # }